@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2014-2020 The mqttwarn developers
+# (c) 2014-2021 The mqttwarn developers
 from builtins import object
 from past.builtins import cmp
 from builtins import chr
@@ -532,15 +532,32 @@ def load_services(services):
 
         module = cf.g('config:' + service, 'module', service)
 
-        if '.' in module:
+        # Load external service from file.
+        modulefile_candidates = []
+        if module.endswith(".py"):
+            # Add two candidates: a) Use the file as given and b) treat the file as relative to
+            # the directory of the configuration file. That retains backward compatibility.
+            modulefile_candidates.append(module)
+            modulefile_candidates.append(os.path.join(cf.configuration_path, module))
+
+        # Load external service with module specification.
+        elif '.' in module:
+            logger.debug('Trying to load service "{}" from module "{}"'.format(service, module))
             try:
                 service_plugins[service]['module'] = load_module_by_name(module)
                 logger.info('Successfully loaded service "{}" from module "{}"'.format(service, module))
+                continue
             except Exception as ex:
                 logger.exception('Unable to load service "{}" from module "{}": {}'.format(service, module, ex))
 
+        # Load built-in service module.
         else:
-            modulefile = resource_filename('mqttwarn.services', module + '.py')
+            modulefile_candidates = [ resource_filename('mqttwarn.services', module + '.py') ]
+
+        for modulefile in modulefile_candidates:
+            if not os.path.isfile(modulefile):
+                continue
+            logger.debug('Trying to load service "{}" from file "{}"'.format(service, modulefile))
             try:
                 service_plugins[service]['module'] = load_module_from_file(modulefile)
                 logger.info('Successfully loaded service "{}"'.format(service))
@@ -562,12 +579,6 @@ def connect():
         logger.error("No services configured. Aborting")
         sys.exit(2)
 
-    try:
-        os.chdir(cf.directory)
-    except Exception as e:
-        logger.error("Cannot chdir to %s: %s" % (cf.directory, e))
-        sys.exit(2)
-
     load_services(services)
 
     # Initialize MQTT broker connection
